Index: trunk/MagicSoft/Mars/mfileio/MCT1ReadAscii.h
===================================================================
--- trunk/MagicSoft/Mars/mfileio/MCT1ReadAscii.h	(revision 2740)
+++ trunk/MagicSoft/Mars/mfileio/MCT1ReadAscii.h	(revision 2781)
@@ -8,13 +8,13 @@
 class TList;
 class MCerPhotEvt;
-class MPedestalCam;
+class MPedPhotCam;
 
 class MCT1ReadAscii : public MTask
 {
 private:
-    ifstream     *fIn;          // the inputfile
-    MCerPhotEvt  *fNphot;       // the data container for all data.
-    MPedestalCam *fPedest;      // ct1 pedestals
-    TList        *fFileNames;   // Array which stores the \0-terminated filenames
+    ifstream    *fIn;        // the inputfile
+    MCerPhotEvt *fNphot;     // the data container for all data.
+    MPedPhotCam *fPedest;    // CT1 pedestals
+    TList       *fFileNames; // Array which stores the \0-terminated filenames
 
     Bool_t OpenNextFile();
Index: trunk/MagicSoft/Mars/mfileio/MCT1ReadPreProc.h
===================================================================
--- trunk/MagicSoft/Mars/mfileio/MCT1ReadPreProc.h	(revision 2740)
+++ trunk/MagicSoft/Mars/mfileio/MCT1ReadPreProc.h	(revision 2781)
@@ -21,5 +21,5 @@
 class MSrcPosCam;
 class MCerPhotEvt;
-class MPedestalCam;
+class MPedPhotCam;
 class MBlindPixels;
 class MRawRunHeader;
@@ -40,5 +40,5 @@
     MGeomCam      *fGeom;    // camera geometry
     MCerPhotEvt   *fNphot;   // the data container for all data.
-    MPedestalCam  *fPedest;  // ct1 pedestals
+    MPedPhotCam   *fPedest;  // ct1 pedestals
     MTime         *fTime;    // event time
     MMcEvt        *fMcEvt;   // monte carlo data container for MC files

Index: trunk/MagicSoft/Mars/mfileio/MCT1ReadAscii.cc
===================================================================
--- trunk/MagicSoft/Mars/mfileio/MCT1ReadAscii.cc	(revision 2740)
+++ trunk/MagicSoft/Mars/mfileio/MCT1ReadAscii.cc	(revision 2781)
@@ -52,6 +52,6 @@
 #include "MCerPhotEvt.h"
 
-#include "MPedestalPix.h"
-#include "MPedestalCam.h"
+#include "MPedPhotPix.h"
+#include "MPedPhotCam.h"
 
 ClassImp(MCT1ReadAscii);
@@ -154,5 +154,5 @@
 // them if they don't exist.
 //
 // Initialize the size of the MPedestalCam container to 127 pixels (CT1 camera)
 //
 Int_t MCT1ReadAscii::PreProcess(MParList *pList)
@@ -178,5 +178,5 @@
     //  look for the pedestal class in the plist
     //
-    fPedest = (MPedestalCam*)pList->FindCreateObj("MPedestalCam");
+    fPedest = (MPedPhotCam*)pList->FindCreateObj("MPedPhotCam");
     if (!fPedest)
         return kFALSE;
@@ -210,6 +210,6 @@
         *fIn >> val;
 
-        if (val > 0.0)
-            (*fPedest)[i].SetPedestalRms(val);
+        if (val>0)
+            (*fPedest)[i].Set(0, val);
     }
 }
@@ -221,11 +221,4 @@
 void MCT1ReadAscii::ReadData()
 {
-    /*
-     //
-     // clear the list of cerphot-events
-     //
-     fNphot->Clear();
-     */
-
     //
     // five unsused numbers
@@ -242,6 +235,4 @@
     // too the list with it's id, number of photons and error
     //
-//    fNphot->InitSize(127);
-
     for (Int_t i = 0; i<127; i++ )
     {
@@ -251,5 +242,5 @@
 
         if (nphot > 0.0)
-            fNphot->AddPixel(i, nphot, (*fPedest)[i].GetPedestalRms());
+            fNphot->AddPixel(i, nphot, (*fPedest)[i].GetRms());
     }
     fNphot->FixSize();
@@ -270,5 +261,5 @@
     // reading event data by the 'switch entry'.
     // After reading it should set the InputStreamID correctly.
-    // ( should use MPedestalCam )
+    // (should use MPedPhotCam )
     //
  
@@ -154,5 +154,5 @@
 // them if they don't exist.
 //
-// Initialize the size of the MPedestalCam container to 127 pixels (CT1 camera)
+// Initialize the size of the MPedPhotCam container to 127 pixels (CT1 camera)
 //
 Int_t MCT1ReadAscii::PreProcess(MParList *pList)
Index: trunk/MagicSoft/Mars/mfileio/MCT1ReadPreProc.cc
===================================================================
--- trunk/MagicSoft/Mars/mfileio/MCT1ReadPreProc.cc	(revision 2740)
+++ trunk/MagicSoft/Mars/mfileio/MCT1ReadPreProc.cc	(revision 2781)
@@ -38,5 +38,5 @@
 //  Output Containers:
 //    MCerPhotEvt     the data container for all data.
-//    MPedestalCam    ct1 pedestals
+//    MPedPhotCam     CT1 pedestals
 //    MMcEvt          monte carlo data container for MC files
 //    MMcTrig         mc data container for trigger information
@@ -67,6 +67,6 @@
 #include "MCerPhotEvt.h"
 
-#include "MPedestalPix.h"
-#include "MPedestalCam.h"
+#include "MPedPhotPix.h"
+#include "MPedPhotCam.h"
 
 #include "MGeomCam.h"
@@ -355,5 +355,5 @@
     for (Int_t i=0; i<iMAXNUMPIX; i++)
     {
-        (*fPedest)[i].SetPedestalRms(outpars.frms_pedsig_phot[i]);
+        (*fPedest)[i].Set(0, outpars.frms_pedsig_phot[i]);
         *fLog << outpars.frms_pedsig_phot[i] << " "; 
         fPedRMS[i] = outpars.frms_pedsig_phot[i];
@@ -722,5 +722,5 @@
 // them if they don't exist.
 //
 // Initialize the size of the MPedestalCam container to 127 pixels (CT1 camera)
 //
 Int_t MCT1ReadPreProc::PreProcess(MParList *pList)
@@ -754,5 +754,5 @@
     //  look for the pedestal class in the plist
     //
-    fPedest = (MPedestalCam*)pList->FindCreateObj("MPedestalCam");
+    fPedest = (MPedPhotCam*)pList->FindCreateObj("MPedPhotCam");
     if (!fPedest)
         return kFALSE;
@@ -901,5 +901,5 @@
     // reset pedestal RMS for this event
     for (Int_t i=0; i<iMAXNUMPIX; i++)
-        (*fPedest)[i].SetPedestalRms(fPedRMS[i]);
+        (*fPedest)[i].Set(0, fPedRMS[i]);
 
     //  int   isecs_since_midday; // seconds passed since midday before sunset (JD of run start)
@@ -944,6 +944,5 @@
             continue;
 
-        fNphot->AddPixel(i, 0.1*event.spixsig_10thphot[i],
-                         (*fPedest)[i].GetPedestalRms());
+        fNphot->AddPixel(i, 0.1*event.spixsig_10thphot[i], (*fPedest)[i].GetRms());
     }
     fNphot->FixSize();
@@ -722,5 +722,5 @@
 // them if they don't exist.
 //
-// Initialize the size of the MPedestalCam container to 127 pixels (CT1 camera)
+// Initialize the size of the MPedPhotCam container to 127 pixels (CT1 camera)
 //
 Int_t MCT1ReadPreProc::PreProcess(MParList *pList)